Installation
------------

CellPyLib3d can be installed via pip:

.. prompt:: bash $

    pip install cellpylib3d

Requirements for using this library are Python 3.7, numpy 1.15.4, and matplotlib 3.0.2.